======
PieODS
======


.. image:: https://img.shields.io/pypi/v/PieODS.svg
        :target: https://pypi.org/project/PieODS

.. image:: https://readthedocs.org/projects/PieODS/badge/?version=stable
        :target: https://PieODS.readthedocs.io/en/stable/?badge=stable
        :alt: Documentation Status




Python interface to the Open Data Service API


* Free software: MIT license
* Documentation: https://pieods.readthedocs.io/en/stable/.
* Releases: https://pypi.org/project/PieODS.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
